.. pymapd documentation master file, created by
   sphinx-quickstart on Fri Jun 23 12:29:54 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pymapd
======

A python `DB-API-2.0`_ compliant interface to `MapD`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _DB-API-2.0: https://www.python.org/dev/peps/pep-0249/
.. _MapD: https://www.mapd.com/
